# Welcome to libtable

[![](https://badgen.net/github/release/sguerri/libtable)](https://github.com/sguerri/libtable/releases/)
[![](https://img.shields.io/github/workflow/status/sguerri/libtable/Build/v0.3.0)](https://github.com/sguerri/libtable/actions/workflows/build.yml)
[![](https://badgen.net/github/license/sguerri/libtable)](https://www.gnu.org/licenses/)
[![](https://badgen.net/pypi/v/libtable)](https://pypi.org/project/libtable/)
[![](https://badgen.net/pypi/python/libtable)](#)
[![](https://badgen.net/badge/Open%20Source%20%3F/Yes%21/blue?icon=github)](#)

> Python library for cli tables

Work in Progress

**Main features**
* TODO

**Roadmap**
* TODO

---

- [Welcome to libtable](#welcome-to-libtable)
  * [Installation](#installation)
  * [Usage](#usage)
  * [Build](#build)
  * [Dependencies](#dependencies)
  * [Author](#author)
  * [Issues](#issues)
  * [License](#license)

## Installation

TODO

## Usage

TODO

## Build

TODO

## Dependencies

**Python Libraries**
- [python-prompt-toolkit](https://github.com/prompt-toolkit/python-prompt-toolkit)

**Python Development Libraries**
- [poetry](https://python-poetry.org/)

## Author

Sébastien Guerri - [github page](https://github.com/sguerri)

## Issues

Contributions, issues and feature requests are welcome!

Feel free to check [issues page](https://github.com/sguerri/libtable/issues). You can also contact me.

## License

Copyright (C) 2022 Sebastien Guerri

libtable is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or any later version.

libtable is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with libtable. If not, see <https://www.gnu.org/licenses/>.